@@ -20,5 +20,5 @@ def ldap_pkg(use_sudo=False, user=None):
     fabtools.require.deb.package('libsasl2-dev', update=True)
     fabtools.require.deb.package('libssl-dev', update=True)
     fabtools.require.python.package(
-        'python-ldap', upgrade=True, use_sudo=use_sudo,
-        user=user)
+        'python-ldap', upgrade=True, use_sudo=use_sudo, user=user
+    )
