@@ -29,14 +29,20 @@ def install_mysql_server(version=None, password=None):
 def add_mysql_user(name, password, host='localhost', **kwargs):
     """ Adds mysql user """
     if not fabtools.mysql.user_exists(name):
-        fabtools.mysql.create_user(
-            name, password=password, host=host, **kwargs)
+        fabtools.mysql.create_user(name, password=password, host=host, **kwargs)
 
 
 @do_verbose
-def add_mysql_database(name, owner=None, owner_host='localhost',
-                       charset='utf8', collate='utf8_general_ci', **kwargs):
+def add_mysql_database(
+    name,
+    owner=None,
+    owner_host='localhost',
+    charset='utf8',
+    collate='utf8_general_ci',
+    **kwargs
+):
     """ Adds mysql database """
     if not fabtools.mysql.database_exists(name):
-        fabtools.mysql.create_database(name, owner=owner, charset=charset,
-                                       collate=collate, **kwargs)
+        fabtools.mysql.create_database(
+            name, owner=owner, charset=charset, collate=collate, **kwargs
+        )
