@@ -31,19 +31,35 @@ def install_postgres_server(update=False):
 
 
 @do_verbose
-def add_postgres_user(name, password, superuser=False, createdb=False,
-                      createrole=False, inherit=True, login=True,
-                      connection_limit=None, encrypted_password=False,
-                      verbose=True):
+def add_postgres_user(
+    name,
+    password,
+    superuser=False,
+    createdb=False,
+    createrole=False,
+    inherit=True,
+    login=True,
+    connection_limit=None,
+    encrypted_password=False,
+    verbose=True,
+):
     """ Installs  postgres server on remote """
     if "verbose_output" in env:
         verbose = env.verbose_output
         msg = ''
 
     if not fabtools.postgres.user_exists(name):
-        fabtools.require.postgres.user(name, password, superuser, createdb,
-                                       createrole, inherit, login,
-                                       connection_limit, encrypted_password)
+        fabtools.require.postgres.user(
+            name,
+            password,
+            superuser,
+            createdb,
+            createrole,
+            inherit,
+            login,
+            connection_limit,
+            encrypted_password,
+        )
         msg = 'Add %s user for postgresql !' % fabric.colors.green(name)
     else:
         msg = 'User %s already exists !' % fabric.colors.red(name)
@@ -53,21 +69,30 @@ def add_postgres_user(name, password, superuser=False, createdb=False,
 
 
 @do_verbose
-def add_postgres_database(name, owner, template='template0', encoding='UTF8',
-                          locale='fr_FR.UTF-8', verbose=True):
+def add_postgres_database(
+    name,
+    owner,
+    template='template0',
+    encoding='UTF8',
+    locale='fr_FR.UTF-8',
+    verbose=True,
+):
     """ Adds  postgresql database on remote """
     if "verbose_output" in env:
         verbose = env.verbose_output
         msg = ''
 
     if not fabtools.postgres.database_exists(name):
-        fabtools.require.postgres.database(name, owner, template, encoding,
-                                           locale)
+        fabtools.require.postgres.database(name, owner, template, encoding, locale)
         msg = 'Add %s database for owner %s !' % (
-            fabric.colors.green(name), fabric.colors.green(owner))
+            fabric.colors.green(name),
+            fabric.colors.green(owner),
+        )
     else:
         msg = 'Database %s for owner %s already exists !' % (
-            fabric.colors.red(name), fabric.colors.red(owner))
+            fabric.colors.red(name),
+            fabric.colors.red(owner),
+        )
 
     if verbose:
         fabric.api.puts(msg)
