@@ -10,12 +10,21 @@ Git vcs relatives methods
 import os
 
 import fabric
+from fabric.api import env
 from pydiploy.decorators import do_verbose
 
 
 @do_verbose
-def archive(filename, path='/tmp', format="tar.gz", tag="HEAD", remote="",
-            prefix="", project_path=".", specific_folder=""):
+def archive(
+    filename,
+    path='/tmp',
+    format="tar.gz",
+    tag="HEAD",
+    remote="",
+    prefix="",
+    project_path=".",
+    specific_folder="",
+):
     """ Creates an archive from a git repository or directly from a project
 
     * Using at the root path of a local cloned repository. This will create
@@ -118,6 +127,10 @@ def collect_branches(project_path='.', remote=""):
 def check_tag_exist(tag=None):
     """ Checks if a tag/branch exists in the repository """
     if tag:
-        if (tag not in collect_branches() and tag not in collect_tags()):
+        if (
+            tag not in collect_branches()
+            and tag not in collect_tags()
+            and 'no_tag_check' not in env
+        ):
             return False
         return True
