@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
 """
-This class is for sytem relatives tools and commands
+This class is for system relatives tools and commands
 
 """
 
+from contextlib import contextmanager
 
 import fabric
 import fabtools
 from fabric.api import env
+
 from pydiploy.decorators import do_verbose
 
 
@@ -27,16 +29,20 @@ def add_user(commands=None):
     """
 
     fabtools.require.group(env.remote_group)
-    fabtools.require.user(env.remote_owner,
-                          create_home=True,
-                          create_group=True,
-                          group=env.remote_group,
-                          shell='/bin/bash')
+    fabtools.require.user(
+        env.remote_owner,
+        create_home=True,
+        create_group=True,
+        group=env.remote_group,
+        shell='/bin/bash',
+    )
     if commands:
-        fabtools.require.sudoer('%%%s' % env.remote_group,
-                                operators='%s,root' % env.remote_owner,
-                                passwd=False,
-                                commands=commands)
+        fabtools.require.sudoer(
+            '%%%s' % env.remote_group,
+            operators='%s,root' % env.remote_owner,
+            passwd=False,
+            commands=commands,
+        )
 
 
 @do_verbose
@@ -59,7 +65,7 @@ def set_locale():
     Sets server's locales
     """
     locale = fabric.api.run("echo $LANG")
-    if(locale != env.locale):
+    if locale != env.locale:
         fabric.api.sudo('locale-gen ' + env.locale)
         fabric.api.sudo('/usr/sbin/update-locale LANG=' + env.locale)
 
@@ -69,11 +75,18 @@ def set_timezone():
     """
     Sets the timezone
     """
-    if fabtools.system.distrib_id() not in('Ubuntu', 'Debian'):
+    if fabtools.system.distrib_id() not in ('Ubuntu', 'Debian'):
         print("Cannot deploy to non-debian/ubuntu host")
         return
 
-    return fabric.api.sudo("cp -f /usr/share/zoneinfo/%s /etc/localtime" % env.timezone)
+    if fabtools.files.is_link("/etc/localtime"):
+        return fabric.api.sudo(
+            "ln -sf /usr/share/zoneinfo/%s /etc/localtime" % env.timezone
+        )
+    else:
+        return fabric.api.sudo(
+            "cp -f /usr/share/zoneinfo/%s /etc/localtime" % env.timezone
+        )
 
 
 @do_verbose
@@ -82,12 +95,17 @@ def permissions():
     Makes the release group-writable
     """
 
-    fabric.api.sudo("chown -R %(user)s:%(group)s %(domain_path)s" %
-                    {'domain_path': env.remote_project_dir,
-                     'user': env.remote_owner,
-                     'group': env.remote_group})
-    fabric.api.sudo("chmod -R g+w %(domain_path)s" %
-                    {'domain_path': env.remote_project_dir})
+    fabric.api.sudo(
+        "chown -R %(user)s:%(group)s %(domain_path)s"
+        % {
+            'domain_path': env.remote_project_dir,
+            'user': env.remote_owner,
+            'group': env.remote_group,
+        }
+    )
+    fabric.api.sudo(
+        "chmod -R g+w %(domain_path)s" % {'domain_path': env.remote_project_dir}
+    )
 
 
 @do_verbose
@@ -112,17 +130,24 @@ def check_python3_install(version='python3', update=False):
     """
 
     if not package_installed(version):
-        if fabtools.system.distrib_id() == 'Ubuntu' and float(fabtools.system.distrib_release()) < 13.10:
-            fabtools.require.deb.packages(['python-software-properties'],
-                                          update=update)
-            fabtools.require.deb.ppa('ppa:fkrull/deadsnakes')
+        # TODO check for others ubuntu"s versions !!!!!
+        # Install mighty PPA
+        if fabtools.system.distrib_release() >= 14.04:
+            # add-apt-repository moved to software-properties-common in 14.04
+            fabtools.require.deb.package('software-properties-common')
+            # deb.pap problem for 20.04 in fabtools
+            fabric.api.sudo('add-apt-repository --yes ppa:deadsnakes/ppa')
+        else:
+            fabtools.require.deb.package('python-software-properties')
+            fabtools.require.deb.ppa('ppa:deadsnakes/ppa')
+
         fabtools.require.deb.package(version, update=True)
 
 
 @do_verbose
 def install_extra_packages(pkg, update=False):
     """
-    Install extra packages on remote server
+    Installs extra packages on remote server
     """
 
     fabtools.require.deb.packages(pkg, update=update)
@@ -132,7 +157,30 @@ def install_extra_packages(pkg, update=False):
 def install_extra_ppa(extra_ppa):
     """
 
-    Install extra ppa source on remote server
+    Installs extra ppa source on remote server
     """
     for ppa in extra_ppa:
         fabtools.require.deb.ppa(ppa)
+
+
+@do_verbose
+def is_systemd():
+    """ Returns True if systemd is used """
+    return fabtools.files.is_dir("/run/systemd/system")
+
+
+@do_verbose
+def install_extra_source(extra_source):
+    """
+
+    Installs extra debian source on remote server
+    """
+    for source in extra_source:
+        fabtools.require.deb.source(*source)
+
+
+@contextmanager
+def shell(new_shell):
+    old_shell, env.shell = env.shell, new_shell
+    yield
+    env.shell = old_shell
