@@ -5,22 +5,28 @@ import copy
 from unittest import TestCase
 
 from fabric.api import env
-from mock import call, Mock, patch
+from mock import Mock, call, patch
 from pydiploy.require.databases.ldap import ldap_pkg
 from pydiploy.require.databases.mongodb import install_mongodb
-from pydiploy.require.databases.mysql import (add_mysql_database,
-                                              add_mysql_user,
-                                              install_mysql_client,
-                                              install_mysql_server)
-from pydiploy.require.databases.oracle import (get_oracle_jdk_version,
-                                               install_oracle_client,
-                                               install_oracle_jdk)
-from pydiploy.require.databases.postgres import (add_postgres_database,
-                                                 add_postgres_user,
-                                                 install_postgres_server,
-                                                 postgres_pkg)
-from pydiploy.require.databases.sqlite import sqlite3_pkg
+from pydiploy.require.databases.mysql import (
+    add_mysql_database,
+    add_mysql_user,
+    install_mysql_client,
+    install_mysql_server,
+)
+from pydiploy.require.databases.oracle import (
+    get_oracle_jdk_version,
+    install_oracle_client,
+    install_oracle_jdk,
+)
+from pydiploy.require.databases.postgres import (
+    add_postgres_database,
+    add_postgres_user,
+    install_postgres_server,
+    postgres_pkg,
+)
 from pydiploy.require.databases.sap import install_sap_client
+from pydiploy.require.databases.sqlite import sqlite3_pkg
 
 
 class LdapCheck(TestCase):
@@ -43,12 +49,20 @@ class LdapCheck(TestCase):
         ldap_pkg()
 
         self.assertTrue(python_package.called)
-        self.assertEqual(python_package.call_args,
-                         call('python-ldap', upgrade=True, use_sudo=False, user=None))
+        self.assertEqual(
+            python_package.call_args,
+            call('python-ldap', upgrade=True, use_sudo=False, user=None),
+        )
 
         self.assertTrue(deb_package.called)
-        self.assertEqual(deb_package.call_args_list,
-                         [call('libldap2-dev', update=True), call('libsasl2-dev', update=True), call('libssl-dev', update=True)])
+        self.assertEqual(
+            deb_package.call_args_list,
+            [
+                call('libldap2-dev', update=True),
+                call('libsasl2-dev', update=True),
+                call('libssl-dev', update=True),
+            ],
+        )
 
 
 class Sqlite3Check(TestCase):
@@ -71,12 +85,13 @@ class Sqlite3Check(TestCase):
         sqlite3_pkg()
 
         self.assertTrue(python_package.called)
-        self.assertEqual(python_package.call_args,
-                         call('pysqlite', upgrade=True, use_sudo=False, user=None))
+        self.assertEqual(
+            python_package.call_args,
+            call('pysqlite', upgrade=True, use_sudo=False, user=None),
+        )
 
         self.assertTrue(deb_package.called)
-        self.assertEqual(deb_package.call_args,
-                         call('libsqlite3-dev', update=True))
+        self.assertEqual(deb_package.call_args, call('libsqlite3-dev', update=True))
 
 
 class PostgresCheck(TestCase):
@@ -100,8 +115,7 @@ class PostgresCheck(TestCase):
         postgres_pkg()
 
         self.assertTrue(deb_packages.called)
-        self.assertEqual(
-            deb_packages.call_args, call(['libpq-dev'], update=False))
+        self.assertEqual(deb_packages.call_args, call(['libpq-dev'], update=False))
 
     @patch("fabtools.require.postgres.server", return_value=Mock())
     def test_install_postgres_server(self, postgres_server):
@@ -116,7 +130,9 @@ class PostgresCheck(TestCase):
         add_postgres_user(name='bill', password='g@t3s')
         self.assertTrue(postgres_user.called)
         self.assertEqual(
-            postgres_user.call_args, call('bill', 'g@t3s', False, False, False, True, True, None, False))
+            postgres_user.call_args,
+            call('bill', 'g@t3s', False, False, False, True, True, None, False),
+        )
 
         # verbose_output = false
         env.verbose_output = False
@@ -127,7 +143,6 @@ class PostgresCheck(TestCase):
         postgres_user_exist.return_value = True
         add_postgres_user(name='bill', password='g@t3s')
 
-
     @patch("fabtools.postgres.database_exists", return_value=False)
     @patch("fabtools.require.postgres.database", return_value=Mock())
     def test_add_postgres_database(self, postgres_database, postgres_db_exists):
@@ -163,8 +178,9 @@ class MysqlCheck(TestCase):
         install_mysql_client()
 
         self.assertTrue(deb_packages.called)
-        self.assertEqual(deb_packages.call_args,
-                         call(['libmysqlclient-dev'], update=False))
+        self.assertEqual(
+            deb_packages.call_args, call(['libmysqlclient-dev'], update=False)
+        )
 
     @patch("fabtools.require.mysql.server", return_value=Mock())
     def test_install_mysql_server(self, mysql_server):
@@ -220,9 +236,11 @@ class OracleCheck(TestCase):
         env.oracle_client_version = '11.2'
         env.oracle_download_url = 'http://librepo.net/lib/oracle/'
         env.oracle_remote_dir = 'oracle_client'
-        env.oracle_packages = ['instantclient-basic-linux-x86-64-11.2.0.2.0.zip',
-                               'instantclient-sdk-linux-x86-64-11.2.0.2.0.zip',
-                               'instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip']
+        env.oracle_packages = [
+            'instantclient-basic-linux-x86-64-11.2.0.2.0.zip',
+            'instantclient-sdk-linux-x86-64-11.2.0.2.0.zip',
+            'instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip',
+        ]
         env.locale = 'fr_FR.UTF-8'
 
     def tearDown(self):
@@ -235,8 +253,9 @@ class OracleCheck(TestCase):
     @patch("fabric.api.cd", return_value=Mock())
     @patch("fabtools.require.files.directory", return_value=Mock())
     @patch("fabtools.require.deb.packages", return_value=Mock())
-    def test_install_oracle_client(self, deb_packages, files_directory,
-                                   api_cd, api_sudo, files_is_link, api_abort):
+    def test_install_oracle_client(
+        self, deb_packages, files_directory, api_cd, api_sudo, files_is_link, api_abort
+    ):
 
         api_cd.return_value.__exit__ = Mock()
         api_cd.return_value.__enter__ = Mock()
@@ -244,45 +263,65 @@ class OracleCheck(TestCase):
         install_oracle_client()
 
         self.assertTrue(deb_packages.called)
-        self.assertEqual(deb_packages.call_args,
-                         call(['libaio-dev', 'unzip']))
+        self.assertEqual(deb_packages.call_args, call(['libaio-dev', 'unzip']))
 
         self.assertTrue(files_directory.called)
-        self.assertEqual(files_directory.call_args,
-                         call(path='/home/django/oracle_client', use_sudo=True, owner='django',
-                              group='di', mode='750'))
+        self.assertEqual(
+            files_directory.call_args,
+            call(
+                path='/home/django/oracle_client',
+                use_sudo=True,
+                owner='django',
+                group='di',
+                mode='750',
+            ),
+        )
 
         self.assertTrue(api_cd.called)
-        self.assertEqual(api_cd.call_args_list,
-                         [call('/home/django'), call('oracle_client/instantclient_11_2')])
+        self.assertEqual(
+            api_cd.call_args_list,
+            [call('/home/django'), call('oracle_client/instantclient_11_2')],
+        )
 
         self.assertTrue(api_sudo.called)
-        self.assertEqual(api_sudo.call_args_list,
-                         [call('wget -c http://librepo.net/lib/oracle/instantclient-basic-linux-x86-64-11.2.0.2.0.zip'),
-                          call(
-                             'unzip instantclient-basic-linux-x86-64-11.2.0.2.0.zip -d oracle_client'),
-                          call(
-                             'rm /home/django/instantclient-basic-linux-x86-64-11.2.0.2.0.zip'),
-                          call(
-                             'wget -c http://librepo.net/lib/oracle/instantclient-sdk-linux-x86-64-11.2.0.2.0.zip'),
-                          call(
-                             'unzip instantclient-sdk-linux-x86-64-11.2.0.2.0.zip -d oracle_client'),
-                          call(
-                             'rm /home/django/instantclient-sdk-linux-x86-64-11.2.0.2.0.zip'),
-                          call(
-                             'wget -c http://librepo.net/lib/oracle/instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip'),
-                          call(
-                             'unzip instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip -d oracle_client'),
-                          call(
-                             'rm /home/django/instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip'),
-                          call('ln -s libclntsh.so.* libclntsh.so'),
-                          call('pwd'),
-                          call(
-                             "echo '# ORACLE CLIENT CONFIGURATION\nexport ORACLE_HOME=/home/django/oracle_client/instantclient_11_2\nexport LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$ORACLE_HOME' >> .bashrc"),
-                             call('source .bashrc'),
-                          call(
-                             'echo /home/django/oracle_client/instantclient_11_2 > /etc/ld.so.conf.d/oracle.conf'),
-                          call('ldconfig')])
+        self.assertEqual(
+            api_sudo.call_args_list,
+            [
+                call(
+                    'wget -c http://librepo.net/lib/oracle/instantclient-basic-linux-x86-64-11.2.0.2.0.zip'
+                ),
+                call(
+                    'unzip instantclient-basic-linux-x86-64-11.2.0.2.0.zip -d oracle_client'
+                ),
+                call('rm /home/django/instantclient-basic-linux-x86-64-11.2.0.2.0.zip'),
+                call(
+                    'wget -c http://librepo.net/lib/oracle/instantclient-sdk-linux-x86-64-11.2.0.2.0.zip'
+                ),
+                call(
+                    'unzip instantclient-sdk-linux-x86-64-11.2.0.2.0.zip -d oracle_client'
+                ),
+                call('rm /home/django/instantclient-sdk-linux-x86-64-11.2.0.2.0.zip'),
+                call(
+                    'wget -c http://librepo.net/lib/oracle/instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip'
+                ),
+                call(
+                    'unzip instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip -d oracle_client'
+                ),
+                call(
+                    'rm /home/django/instantclient-sqlplus-linux-x86-64-11.2.0.2.0.zip'
+                ),
+                call('ln -s libclntsh.so.* libclntsh.so'),
+                call('pwd'),
+                call(
+                    "echo '# ORACLE CLIENT CONFIGURATION\nexport ORACLE_HOME=/home/django/oracle_client/instantclient_11_2\nexport LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$ORACLE_HOME' >> .bashrc"
+                ),
+                call('source .bashrc'),
+                call(
+                    'echo /home/django/oracle_client/instantclient_11_2 > /etc/ld.so.conf.d/oracle.conf'
+                ),
+                call('ldconfig'),
+            ],
+        )
 
         del env['oracle_client_version']
         install_oracle_client()
@@ -298,8 +337,7 @@ class OracleCheck(TestCase):
         install_oracle_jdk(version='7u25-b15')
 
         self.assertTrue(oracle_jdk_install.called)
-        self.assertEqual(
-            oracle_jdk_install.call_args, call(version='7u25-b15'))
+        self.assertEqual(oracle_jdk_install.call_args, call(version='7u25-b15'))
 
     @patch("fabtools.oracle_jdk.version", return_value=Mock())
     def test_oracle_jdk_version(self, jdk_version):
@@ -328,8 +366,9 @@ class MongoCheck(TestCase):
     @patch("fabric.api.sudo", return_value=Mock())
     @patch("fabtools.require.deb.source", return_value=Mock())
     @patch("pydiploy.require.system.package_installed", return_value=True)
-    def test_install_mongodb(self, is_package_installed, deb_source, api_sudo,
-                             uptodate_index, deb_package):
+    def test_install_mongodb(
+        self, is_package_installed, deb_source, api_sudo, uptodate_index, deb_package
+    ):
 
         # nothing to do
         install_mongodb()
@@ -341,17 +380,25 @@ class MongoCheck(TestCase):
         self.assertTrue(is_package_installed.called)
 
         self.assertTrue(deb_source.called)
-        self.assertEqual(deb_source.call_args,
-                         call('mongodb',
-                              'http://downloads-distro.mongodb.org/repo/ubuntu-upstart',
-                              'dist', '10gen'))
+        self.assertEqual(
+            deb_source.call_args,
+            call(
+                'mongodb',
+                'http://downloads-distro.mongodb.org/repo/ubuntu-upstart',
+                'dist',
+                '10gen',
+            ),
+        )
         self.assertTrue(api_sudo.called)
-        self.assertEqual(api_sudo.call_args,
-                         call('apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv 7F0CEB10'))
+        self.assertEqual(
+            api_sudo.call_args,
+            call(
+                'apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv 7F0CEB10'
+            ),
+        )
         self.assertTrue(uptodate_index.called)
         self.assertTrue(deb_package.called)
-        self.assertEqual(deb_package.call_args,
-                         call('mongodb-10gen'))
+        self.assertEqual(deb_package.call_args, call('mongodb-10gen'))
 
 
 class SAPCheck(TestCase):
@@ -383,8 +430,9 @@ class SAPCheck(TestCase):
     @patch("fabric.api.cd", return_value=Mock())
     @patch("fabtools.require.files.directory", return_value=Mock())
     @patch("fabtools.require.deb.packages", return_value=Mock())
-    def test_install_sap_client(self, deb_packages, files_directory,
-                                api_cd, api_sudo, files_is_link, api_abort):
+    def test_install_sap_client(
+        self, deb_packages, files_directory, api_cd, api_sudo, files_is_link, api_abort
+    ):
 
         api_cd.return_value.__exit__ = Mock()
         api_cd.return_value.__enter__ = Mock()
@@ -392,25 +440,27 @@ class SAPCheck(TestCase):
         install_sap_client()
 
         self.assertTrue(deb_packages.called)
-        self.assertEqual(deb_packages.call_args,
-                         call(['libstdc++5']))
+        self.assertEqual(deb_packages.call_args, call(['libstdc++5']))
 
         self.assertTrue(files_directory.called)
-        self.assertEqual(files_directory.call_args,
-                         call(path='/usr/sap', use_sudo=True, mode='755'))
+        self.assertEqual(
+            files_directory.call_args, call(path='/usr/sap', use_sudo=True, mode='755')
+        )
 
         self.assertTrue(api_cd.called)
-        self.assertEqual(api_cd.call_args_list,
-                         [call('/usr/sap'), call('/lib')])
+        self.assertEqual(api_cd.call_args_list, [call('/usr/sap'), call('/lib')])
 
         self.assertTrue(api_sudo.called)
-        self.assertEqual(api_sudo.call_args_list, [
-            call('wget -c http://librepo.net/lib/sap/rfcsdk_64.tar.gz'),
-            call('tar xvf rfcsdk_64.tar.gz'),
-            call('chmod -R 755 rfcsdk'),
-            call('rm rfcsdk_64.tar.gz'),
-            call('ln -s /usr/sap/rfcsdk/lib/librfccm.so .')
-        ])
+        self.assertEqual(
+            api_sudo.call_args_list,
+            [
+                call('wget -c http://librepo.net/lib/sap/rfcsdk_64.tar.gz'),
+                call('tar xvf rfcsdk_64.tar.gz'),
+                call('chmod -R 755 rfcsdk'),
+                call('rm rfcsdk_64.tar.gz'),
+                call('ln -s /usr/sap/rfcsdk/lib/librfccm.so .'),
+            ],
+        )
 
         del env['sap_download_url']
         install_sap_client()
